{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "bgzip VCF",
            "baseCommand": [
                "/opt/htslib/bin/bgzip"
            ],
            "stdout": "$(inputs.file.basename).gz",
            "arguments": [
                "-c"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#bgzip.cwl/file"
                }
            ],
            "id": "#bgzip.cwl",
            "outputs": [
                {
                    "type": "File",
                    "id": "#bgzip.cwl/bgzipped_file",
                    "outputBinding": {
                        "glob": "$(inputs.file.basename).gz"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "vcf index",
            "arguments": [
                "cp",
                "$(inputs.vcf.path)",
                "$(runtime.outdir)/$(inputs.vcf.basename)",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "/usr/bin/tabix",
                "-p",
                "vcf"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "valueFrom": "$(self.basename)",
                        "position": 1
                    },
                    "id": "#index.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.vcf.basename)"
                    },
                    "id": "#index.cwl/indexed_vcf"
                }
            ],
            "id": "#index.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "add GT tags",
            "arguments": [
                "/usr/bin/perl",
                "/usr/bin/add_strelka_gt.pl",
                "$(inputs.vcf.path)",
                "$(runtime.outdir)"
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#add_gt.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "add_gt.vcf"
                    },
                    "id": "#add_gt.cwl/processed_vcf"
                }
            ],
            "id": "#add_gt.cwl"
        },
        {
            "class": "Workflow",
            "label": "process VCF workflow",
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/index/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/processed_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#add_gt.cwl",
                    "in": [
                        {
                            "source": "#main/vcf",
                            "id": "#main/add_gt/vcf"
                        }
                    ],
                    "out": [
                        "#main/add_gt/processed_vcf"
                    ],
                    "id": "#main/add_gt"
                },
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#main/add_gt/processed_vcf",
                            "id": "#main/bgzip/file"
                        }
                    ],
                    "out": [
                        "#main/bgzip/bgzipped_file"
                    ],
                    "id": "#main/bgzip"
                },
                {
                    "run": "#index.cwl",
                    "in": [
                        {
                            "source": "#main/bgzip/bgzipped_file",
                            "id": "#main/index/vcf"
                        }
                    ],
                    "out": [
                        "#main/index/indexed_vcf"
                    ],
                    "id": "#main/index"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
